import setuptools

setuptools.setup(
    name="pyenglish",
    version="0.0.2",
    license='MIT',
    author="Jung Ji-Hyo",
    author_email="cord0318@gmail.com",
    description="영어 공부를 도와주는 모듈.",
    classifiers=[
        # 패키지에 대한 태그
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent"
    ],
)